@@ -1,6 +1,6 @@
 """Loader"""
 
-from typing import Any, Dict, Mapping, Optional
+from typing import Any, Dict, Mapping, Optional, Union
 
 from ..meta_data import ProtocolMetaData
 from ..types import ValueType
@@ -14,7 +14,7 @@ def load_protocol(
         *,
         is_millisecond_time: bool = True,
         is_float_decimal: bool = False,
-        is_type_enum: Optional[Mapping[ValueType, bool]] = None
+        is_type_enum: Optional[Mapping[Union[ValueType, str], bool]] = None
 ) -> ProtocolMetaData:
     """Load a protocol
 
@@ -24,9 +24,9 @@ def load_protocol(
             Defaults to True.
         is_float_decimal (bool, optional): If true use Decimal for floating
             point numbers. Defaults to False.
-        is_type_enum (Optional[Mapping[ValueType, bool]], optional): An optional
-            map to control the serialization of types to enums. Defaults to
-            None.
+        is_type_enum (Optional[Mapping[Union[ValueType, str], bool]], optional):
+            An optional map to control the serialization of types to enums.
+            Defaults to None.
 
     Returns:
         ProtocolMetaData: The protocol meta data.
